@@ -109,6 +109,7 @@ def jgtxplot18c_231209(
     # @STCIssue Desired Number of Bars ALREADY SELECTED IN THERE
     # print(len(data))
     # data.to_csv("debug_data" + instrument.replace("/","-") + timeframe + ".csv")
+    fig,axes,cdfdata=None,None,None
     try:
         fig, axes, cdfdata = plot_from_cds_df(
             data,
@@ -124,7 +125,7 @@ def jgtxplot18c_231209(
         if fig is not None:
             print("   Fig is not none so we return it and wont try the ALT")
             return fig, axes, cdfdata
-        if rq.verbose_level> 1:
+        if rq is not None and rq.verbose_level> 1:
             print("Error plotting regular ADS for:" + instrument + " " + timeframe + ", exception: " + str(e))
             traceback.print_exc()
         print("ALT Plotting (" + instrument + " " + timeframe + ")" )
@@ -305,6 +306,7 @@ def plot_from_cds_df(
     if nb_bar_on_chart != tst_len_data: #@STCIssue Isn't this already done ???
         data_last_selection = _select_charting_nb_bar_on_chart(data, nb_bar_on_chart)
     l_datasel = len(data_last_selection)
+    desired_number_of_bars=l_datasel>=nb_bar_on_chart
 
     # Make OHLC bars plot
     ohlc = data_last_selection[[OPEN, HIGH, LOW, CLOSE]]
@@ -389,9 +391,10 @@ def plot_from_cds_df(
             print("Added AO ABove/Bellow Peaks plot")
         
         
+    price_peak_offset_value = average_bar_height / 3 * 5
+    
     # PRICE_PEAK_ABOVE / PRICE_PEAK_ABOVE
     if plot_ao_peaks and cc.show_price_peak:
-        price_peak_offset_value = average_bar_height / 3 * 5
 
 
         data_last_selection.loc[:, PRICE_PEAK_ABOVE] = np.where(
@@ -462,12 +465,12 @@ def plot_from_cds_df(
 
      
     # FDB
+    fdb_tick_offset = average_bar_height  # pipsize * 111
+    fdb_offset_value = average_bar_height / 2  # pipsize * fdb_tick_offset
     if cc.show_fdb_signal:
 
 
            
-        fdb_tick_offset = average_bar_height  # pipsize * 111
-        fdb_offset_value = average_bar_height / 2  # pipsize * fdb_tick_offset
 
         fdbb_up_plot, fdbs_down_plot = make_plot__fdb_signals(
             data=data_last_selection,
@@ -606,12 +609,7 @@ def plot_from_cds_df(
 
 
        
-            
-
-    tst_addplot = len(addplot)
-
-    if not rq.quiet:
-        print("addplot count: " + str(tst_addplot))
+    
     #print("addplot dict : " + str(addplot))
 
     # get date time of the last bar
@@ -640,7 +638,6 @@ def plot_from_cds_df(
 
     if rq.verbose_level> 1:
         print("Chart fmt :",fmt)
-        
     fig, axes = mpf.plot(
         ohlc,
         type=cc.main_plot_type,
@@ -872,7 +869,7 @@ def save_add_figure(instrument, timeframe, rq, fig):
                 os.path.isdir(rq.save_additional_figures_path) and not is_an_image_path
             ) or last_char_is_slash or rq.save_additional_figures_path == "pov":
             try:
-                os.path.mkdir(rq.save_additional_figures_path, exist_ok=True)
+                os.makedirs(rq.save_additional_figures_path, exist_ok=True)
             except:
                 pass
             exn = ".png"
@@ -1052,6 +1049,9 @@ def plot_from_cds_df_ALT(
     # Set the font size of the Date column
     axes[main_plot_panel_id].tick_params(axis="x", labelsize=6)
 
+    if rq.save_additional_figures_path is not None:
+        save_add_figure(instrument, timeframe, rq, fig)
+    
     if show:
         plt.show()
     return fig, axes, data_last_selection
@@ -1459,35 +1459,43 @@ def plot(
 
 import argparse
 
-
 def main():
-    print("JGTADS v0.1")
+    from jgtutils import jgtcommon
+    from jgtpyconstants import ADSCLI_PROG_DESCRIPTION, ADSCLI_PROG_NAME, ADSCLI_PROG_EPILOG
+    
+    #print("JGTADS v0.1")
     # Parse arguments
-    parser = argparse.ArgumentParser(description="Plot the chart for a given instrument and timeframe.")
-    parser.add_argument("-i","--instrument", type=str, help="The name of the instrument.",required=True,metavar="instrument")
-    parser.add_argument("-t","--timeframe", type=str, help="The timeframe for the chart.",required=True,metavar="timeframe")
+    parser=jgtcommon.new_parser(ADSCLI_PROG_DESCRIPTION,ADSCLI_PROG_EPILOG,ADSCLI_PROG_NAME)
+
+    parser=jgtcommon.add_instrument_timeframe_arguments(parser)
+    
+    # parser.add_argument("-i","--instrument", type=str, help="The name of the instrument.",required=True,metavar="instrument")
+    # parser.add_argument("-t","--timeframe", type=str, help="The timeframe for the chart.",required=True,metavar="timeframe")
+    
     #use fresh
-    parser.add_argument("-uf","--fresh", action="store_true", help="Whether to use fresh data.",default=False)
+    parser=jgtcommon.add_use_fresh_argument(parser)
+    #parser.add_argument("-uf","--fresh", action="store_true", help="Whether to use fresh data.",default=False)
     #crop dt
     parser.add_argument("-dt","--crop_last_dt", type=str, help="The last date-time to crop the data.")
-    parser.add_argument("-s","--show", action="store_true", help="Whether to display the plot.",default=False)
+    parser.add_argument("--show", action="store_true", help="Whether to display the plot.",default=False)
     #save figure 
     parser.add_argument("-sf", "--save_figure", type=str, help="Save the figure to the given path.",default=None)
     #save_figure_as_pov_name flag
     parser.add_argument("-pov", "--save_figure_as_pov_name", action="store_true", help="Save the figure as pov file.",default=False)
     #save dpi
     parser.add_argument("-dpi", "--save_additional_figures_dpi", type=int, help="The DPI of the saved figures.",default=300)
-    #verbose level
-    parser.add_argument("-v","--verbose_level", type=int, help="The verbose level.",default=0)
     
-    args = parser.parse_args()
+    parser=jgtcommon.add_verbose_argument(parser)
+    #verbose level
+    
+    args=jgtcommon.parse_args(parser)
     if not args.show and args.save_figure is None and args.save_figure_as_pov_name is False:
-        print("No output will be generated. Use -s or -sf to display or save the figure.")
+        print("No output will be generated. Use -show or -sf to display or save the figure.")
         return
 
     # Create a JGTADSRequest object
     rq = JGTADSRequest()
-    rq.verbose_level = args.verbose_level
+    rq.verbose_level = args.verbose
 
     # Set the instrument and timeframe
     rq.instrument = args.instrument
@@ -1520,4 +1528,4 @@ def main():
         plot_v2(rq, BETA_TRY=True)
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
