@@ -10,6 +10,7 @@ sys.path.insert(0, os.path.abspath(os.path.dirname(__file__)))
 
 
 import pandas as pd
+pd.options.mode.copy_on_write = True
 import datetime
 from JGTPDHelper import (
     jgtpd_drop_col_by_name,
@@ -79,9 +80,10 @@ from jgtutils.jgtconstants import (
     FL34,
     FL55,
     FL89,
-    MFI
+    MFI,
+    ZONE_SIGNAL,
 )
-
+from jgtutils.colconverthelper import zone_str_to_id
 
 # %%
 # @title Range shift add col drop na
@@ -256,7 +258,7 @@ def ids_add_indicators_LEGACY(
     big_alligator=False,
     balligator_period_jaws=89,
     largest_fractal_period=89,
-    min_nb_bar_on_chart=300,
+    min_nb_bar_on_chart=NB_BARS_BY_DEFAULT_IN_CDS,
     bypass_index_reset=False,
     ids_request: JGTIDSRequest = None,
 ):
@@ -272,7 +274,7 @@ def ids_add_indicators_LEGACY(
     addAlligatorOffsetInFutur (bool, optional): (NOT IMPLEMENTED) Whether to add the Alligator offset in the future. Defaults to True.
     big_alligator_jaws_period (int, optional): (NOT IMPLEMENTED) The period of the Alligator jaws. Defaults to 89.
     largest_fractal_period (int, optional): (NOT IMPLEMENTED) The largest fractal period. Defaults to 89.
-    min_nb_bar_on_chart (int, optional): The minimum number of bars on the chart. Defaults to 300.
+    min_nb_bar_on_chart (int, optional): The minimum number of bars on the chart. Defaults to NB_BARS_BY_DEFAULT_IN_CDS.
     bypass_index_reset (bool, optional): Whether to bypass resetting the index. Defaults to False.
     ids_request (JGTIDSRequest, optional): The JGTIDSRequest object. Defaults to None.
 
@@ -944,7 +946,7 @@ def _add_ao_fractal_peak_v1(
 
 # @title Add CDS signals
 
-from jgtutils.jgtconstants import MFI,MFI_SQUAT,MFI_GREEN,MFI_FADE,MFI_FAKE,MFI_SIGNAL,MFI_VAL
+from jgtutils.jgtconstants import MFI,MFI_SQUAT,MFI_GREEN,MFI_FADE,MFI_FAKE,MFI_SIGNAL,MFI_VAL,MFI_SQUAT_STR,MFI_FAKE_STR,MFI_FADE_STR,MFI_GREEN_STR,MFI_SQUAT_ID,MFI_FAKE_ID,MFI_FADE_ID,MFI_GREEN_ID
 
 def _cds_add_mfi_squat_n_signals_column_logics_v1(dfsrc, quiet=False):
     """
@@ -957,7 +959,7 @@ def _cds_add_mfi_squat_n_signals_column_logics_v1(dfsrc, quiet=False):
     Returns:
     - dfsrc (DataFrame): The updated DataFrame with the MFI squat column logics added.
     """
-
+    #@STCIssue If MFI Flags off that bugs. 'DataFrame' object has no attribute 'mfi'
     dfsrc[MFI_SQUAT] = (
         (dfsrc.Volume > 0)
         & (dfsrc.Volume > dfsrc.Volume.shift())
@@ -979,10 +981,14 @@ def _cds_add_mfi_squat_n_signals_column_logics_v1(dfsrc, quiet=False):
         & (dfsrc.mfi > dfsrc.mfi.shift())
         ).astype(int)
     dfsrc[MFI_SIGNAL] = dfsrc.apply(
-         lambda row: 4 if row[MFI_SQUAT] > 0 else 1 if row[MFI_GREEN] > 0 else 2 if row[MFI_FADE]>0 else 3 if row[MFI_FAKE]>0 else 0 , axis=1
+         lambda row: MFI_SQUAT_ID if row[MFI_SQUAT] > 0 else MFI_GREEN_ID if row[MFI_GREEN] > 0 else MFI_FADE_ID if row[MFI_FADE]>0 else MFI_FAKE_ID if row[MFI_FAKE]>0 else 0 , axis=1
      )
+    #MFI_GREEN_STR = "++"
+    #MFI_FADE_STR = "--"
+    #MFI_FAKE_STR = "-+"
+    #MFI_SQUAT_STR = "+-"
     dfsrc[MFI_VAL] = dfsrc.apply(
-         lambda row: "++" if row[MFI_SIGNAL] == 1 else "--" if row[MFI_SIGNAL] == 2 else "-+" if row[MFI_SIGNAL] == 3 else "+-" if row[MFI_SIGNAL] == 4 else "0" , axis=1)
+         lambda row: MFI_GREEN_STR if row[MFI_SIGNAL] == MFI_GREEN_ID else MFI_FADE_STR if row[MFI_SIGNAL] == MFI_FADE_ID else MFI_FAKE_STR if row[MFI_SIGNAL] == MFI_FAKE_ID else MFI_SQUAT_STR if row[MFI_SIGNAL] == MFI_SQUAT_ID else "0" , axis=1)
     return dfsrc
 
 
@@ -1129,9 +1135,9 @@ def jgti_add_zlc_plus_other_AO_signal(
         aobz = dfsrc.at[i, AOBZ]
 
         # ZLC
-        isZLCBuy = 0
-        isZLCSell = 0
-        zlcCode = 0
+        isZLCBuy:int = 0
+        isZLCSell:int = 0
+        zlcCode:int = 0
         if pao1 > 0 and aobz == 1:
             zlcCode = -1
             isZLCSell = 1
@@ -1139,9 +1145,9 @@ def jgti_add_zlc_plus_other_AO_signal(
             zlcCode = 1
             isZLCBuy = 1
 
-        dfsrc.at[i, ZLC] = zlcCode
-        dfsrc.at[i, ZLCB] = isZLCBuy
-        dfsrc.at[i, ZLCS] = isZLCSell
+        dfsrc.at[i, ZLC] = int(zlcCode)
+        dfsrc.at[i, ZLCB] = int(isZLCBuy)
+        dfsrc.at[i, ZLCS] = int(isZLCSell)
 
         # dfsrc[signal_zcol_column_name] = dfsrc[signal_zcol_column_name].astype(object)
         # Coloring AO
@@ -1165,27 +1171,28 @@ def jgti_add_zlc_plus_other_AO_signal(
 
         zoneColor = nonTradingZoneColor  # default Zone Color
 
-        redZone = 0
+        redZone:int = 0
         if cacred and caored and pac1red and pao1red:
-            redZone = 1
+            redZone:int = 1
             zoneColor = sellingZoneColor
 
-        greenZone = 0
+        greenZone:int = 0
         if cacgreen and caogreen and pac1green and pao1green:
             greenZone = 1
             zoneColor = buyingZoneColor
 
         dfsrc.at[i, signal_zcol_column_name] = zoneColor
+        dfsrc.at[i, ZONE_SIGNAL] = int(zone_str_to_id(zoneColor))
 
         # Sell Zone Signal
 
-        dfsrc.at[i, SZ] = redZone
+        dfsrc.at[i, SZ] = int(redZone)
 
         # Buy Zone Signal
-        dfsrc.at[i, BZ] = greenZone
+        dfsrc.at[i, BZ] = int(greenZone)
 
         # AC Sell / Buy  3 AC Against AO af AC Bellow, 2 if above
-        acSell = 0
+        acSell:int = 0
         msgacSignal = "No "
         if cacred and pac1red and caogreen and pao1green:
             acSell = 1
@@ -1193,7 +1200,7 @@ def jgti_add_zlc_plus_other_AO_signal(
                 cac < 0 and pac2green
             ):  # We require 3 bars red on the AC When bellow zero
                 acSell = 0
-        acBuy = 0
+        acBuy:int = 0
         if cacgreen and pac1green and caored and pao1red:
             acBuy = 1
             if cac > 0 and pac2red:
@@ -1201,10 +1208,10 @@ def jgti_add_zlc_plus_other_AO_signal(
 
         # AC Sell Signal (Deceleration)
 
-        dfsrc.at[i, ACS] = acSell
+        dfsrc.at[i, ACS] = int(acSell)
 
         # AC Buy Signal (Acceleration)
-        dfsrc.at[i, ACB] = acBuy
+        dfsrc.at[i, ACB] = int(acBuy)
 
         if acSell and not quiet:
             print("AC Sell Signal with AC Bellow Zero Line " + str(i))
@@ -1213,16 +1220,16 @@ def jgti_add_zlc_plus_other_AO_signal(
 
         # Saucer Strategy
         # More on Saucer Strategy : http://simp.ly/p/2K1HBr
-        saucerSell = 0
+        saucerSell:int = 0
         if cao < 0 and caored and pao1green and pao2green:
             saucerSell = 1
 
-        saucerBuy = 0
+        saucerBuy:int = 0
         if cao > 0 and caogreen and pao1red and pao2red:
             saucerBuy = 1
 
-        dfsrc.at[i, SS] = saucerSell
-        dfsrc.at[i, SB] = saucerBuy
+        dfsrc.at[i, SS] = int(saucerSell)
+        dfsrc.at[i, SB] = int(saucerBuy)
 
         # What Happens on the Next PLUS 35 Periods ??
         if c < xc - 35:
