@@ -1,6 +1,7 @@
 #!/usr/bin/env python -0 
 
 # %% Imports
+import datetime
 import sys
 import os
 
@@ -20,8 +21,9 @@ import matplotlib.pyplot as plt
 plt.rcParams["figure.max_open_warning"] = 100
 
 import pandas as pd
-from jgtpy import JGTADS as ads, adshelper as ah, JGTPDSP as pds, JGTADSRequest as RQ
-from jgtpy import JGTChartConfig
+import JGTADS as ads, adshelper as ah, JGTPDSP as pds, JGTADSRequest as RQ
+import JGTChartConfig
+from jgtutils.jgtconstants import NB_BARS_BY_DEFAULT_IN_CDS
 
 import tlid
 
@@ -32,7 +34,7 @@ def create_default_chart_config():
     cc.ac_signals_marker_size = 14
     cc.fig_ratio_x = 31
     cc.fig_ratio_y = 16
-    cc.nb_bar_on_chart = 300
+    cc.nb_bar_on_chart = NB_BARS_BY_DEFAULT_IN_CDS
     cc.plot_style = "yahoo"
     return cc
   
@@ -90,6 +92,8 @@ def generate_market_snapshots(instruments:str, timeframes:str, html_outdir_root:
       print("Environment variable JGTPY_DATA is not set. Default to ./charts.")
       
       html_outdir_root = os.path.join(default_chart_output_dir,default_char_dir_name)
+  if timeframes is None:
+    timeframes=os.getenv("T")
   timeframes = timeframes.split(",")
   perspectives = {}
   ptabs = pn.Tabs(width=width, height=height)
@@ -217,6 +221,10 @@ def generate_market_snapshots_for_many_crop_dt(i:str, timeframes, crop_last_dt_a
 
   html_outdir_root = _mk_html_outdir_root_default(html_outdir_root, default_char_dir_name, default_chart_output_dir, jgtpy_data_var)
 
+  if timeframes is None:
+    from jgtutils.jgtconstants import TIMEFRAMES_DEFAULT
+    timeframes = os.getenv("T", TIMEFRAMES_DEFAULT)
+  
   if isinstance(timeframes, str):
     timeframes = timeframes.split(",")
 
@@ -365,10 +373,17 @@ def pto_generate_snapshot_240302_v2_by_crop_dates(
   ifn = i.replace("/", "-")
   subdir_scene_name = f"{ifn}_{tf_of_signal}_{sig_type_name}_{scntlid}"  # GBP-USD_2307132100
 
-  if scn_root_dir is None:
+  if scn_root_dir is None or scn_root_dir=="__DATA__" or scn_root_dir=="_d":
+    scn_root_dir = os.environ["JGTPY_DATA"]
+    
+  if scn_root_dir is None or scn_root_dir=="__FULL__" or scn_root_dir=="_f":
     scn_root_dir = os.environ["JGTPY_DATA_FULL"]
   
-  scn_chart_dir = os.path.join(os.path.join(scn_root_dir,  default_char_dir_name), subdir_scene_name)
+  if scn_root_dir == "." or scn_root_dir=="__CURR__" or scn_root_dir=="_c" or scn_root_dir=="cwd":
+    scn_root_dir = os.getcwd()
+  
+  default_char_dir_name_fixed=default_char_dir_name.replace("/","-")
+  scn_chart_dir = os.path.join(os.path.join(scn_root_dir,  default_char_dir_name_fixed), subdir_scene_name)
   os.makedirs(scn_chart_dir, exist_ok=True)
   
   
@@ -427,60 +442,62 @@ def _mk_html_outdir_root_default(html_outdir_root, default_char_dir_name, defaul
 import argparse
 
 def main():
-  
-    parser = argparse.ArgumentParser(description='CLI for mksg functions')
-    
-    parser.add_argument('-i','--instrument', type=str, required=True)
-    parser.add_argument('-t','--timeframes', type=str, required=True)
-    parser.add_argument('-tos','--tf_of_signal', type=str, required=False)
-    parser.add_argument('-st','--sig_type_name', type=str, required=False, default="")
-    parser.add_argument('-cl','--crop_last_dt', type=str, required=False,help="crop date(s) in the format '2022-10-13 13:45:00' or '2022-10-13 13:45:00,2022-10-13 13:45:00' ")
-    parser.add_argument('-o','--scn_root_dir', type=str, default=None)
-    parser.add_argument('-d','--default_char_dir_name', type=str, default="charts")
-    parser.add_argument('--show_chart', type=bool, default=False)
-    parser.add_argument('--show_tabs', type=bool, default=False)
-    parser.add_argument('--save_fig_image', type=bool, default=True)
-    parser.add_argument('--save_cds_data', type=bool, default=True)
-    parser.add_argument('--out_htm_viewer_full_fn', type=str, default="index.html")
-    parser.add_argument('--out_htm_viewer_prefix', type=str, default="_index-")
-    parser.add_argument('--width', type=int, default=2550)
-    parser.add_argument('--height', type=int, default=1150)
-    #add seerve it
-    parser.add_argument('-svr','--serve_it', type=bool, default=False)
+  from jgtutils import jgtcommon as jgtcommon
+  from jgtpyconstants import MKSCLI_PROG_DESCRIPTION, MKSCLI_PROG_NAME, MKSCLI_PROG_EPILOG
+  parser=jgtcommon.new_parser(MKSCLI_PROG_DESCRIPTION,MKSCLI_PROG_EPILOG,MKSCLI_PROG_NAME)
+  parser=jgtcommon.add_instrument_timeframe_arguments(parser)
+  #parser.add_argument('-i','--instrument', type=str, required=True)
+  #parser.add_argument('-t','--timeframes', type=str, required=False)
+  parser.add_argument('-tos','--tf_of_signal', type=str, required=False)
+  parser.add_argument('-st','--sig_type_name', type=str, required=False, default="")
+  parser.add_argument('-cl','--crop_last_dt', type=str, required=False,help="crop date(s) in the format '2022-10-13 13:45:00' or '2022-10-13 13:45:00,2022-10-13 13:45:00' ")
+  parser.add_argument('-srd','--scn_root_dir', type=str, default=None)
+  parser.add_argument('-dcdn','--default_char_dir_name', type=str, default="charts")
+  parser.add_argument('--show_chart', type=bool, default=False)
+  parser.add_argument('--show_tabs', type=bool, default=False)
+  parser.add_argument('--save_fig_image', type=bool, default=True)
+  parser.add_argument('--save_cds_data', type=bool, default=True)
+  parser.add_argument('--out_htm_viewer_full_fn', type=str, default="index.html")
+  parser.add_argument('--out_htm_viewer_prefix', type=str, default="_index-")
+  parser.add_argument('--width', type=int, default=2550)
+  parser.add_argument('--height', type=int, default=1150)
+  #add seerve it
+  parser.add_argument('-svr','--serve_it', type=bool, default=False)
 
-    args = parser.parse_args()
-  
+  args = jgtcommon.parse_args(parser)
 
-    if args.tf_of_signal is None or args.sig_type_name is None:
-      print("Generating market snapshots for the given instruments and timeframes")
-      generate_market_snapshots(
-        instruments=args.instrument,
-        timeframes=args.timeframes,
-        html_outdir_root=args.scn_root_dir,
-        cc=None,
-        crop_last_dt=args.crop_last_dt
-        
-      )
-    else:
-      print("Generating market snapshots for multiple crop dates / signal dates")
-      pto_generate_snapshot_240302_v2_by_crop_dates(
-        i=args.instrument,
-        timeframes=args.timeframes,
-        tf_of_signal=args.tf_of_signal,
-        sig_type_name=args.sig_type_name,
-        crop_last_dt_arr=args.crop_last_dt_arr,
-        scn_root_dir=args.scn_root_dir,
-        default_char_dir_name=args.default_char_dir_name,
-        show_chart=args.show_chart,
-        show_tabs=args.show_tabs,
-        save_fig_image=args.save_fig_image,
-        save_cds_data=args.save_cds_data,
-        out_htm_viewer_full_fn=args.out_htm_viewer_full_fn,
-        out_htm_viewer_prefix=args.out_htm_viewer_prefix,
-        w=args.width,
-        h=args.height,
-        serve_it=args.serve_it
-      )
+
+  if args.tf_of_signal is None or args.sig_type_name is None:
+    print("Generating market snapshots for the given instruments and timeframes")
+    generate_market_snapshots(
+      instruments=args.instrument,
+      timeframes=args.timeframes,
+      html_outdir_root=args.scn_root_dir,
+      cc=None,
+      crop_last_dt=args.crop_last_dt
+      
+    )
+  else:
+    print("Generating market snapshots for multiple crop dates / signal dates")
+    crop_last_dt_arr = args.crop_last_dt_arr if hasattr(args,"crop_last_dt_arr")  else datetime.datetime.now(tz=datetime.timezone.utc).strftime("%Y-%m-%d %H:%M:%S")
+    pto_generate_snapshot_240302_v2_by_crop_dates(
+      i=args.instrument,
+      timeframes=args.timeframes,
+      tf_of_signal=args.tf_of_signal,
+      sig_type_name=args.sig_type_name,
+      crop_last_dt_arr=crop_last_dt_arr,
+      scn_root_dir=args.scn_root_dir,
+      default_char_dir_name=args.default_char_dir_name,
+      show_chart=args.show_chart,
+      show_tabs=args.show_tabs,
+      save_fig_image=args.save_fig_image,
+      save_cds_data=args.save_cds_data,
+      out_htm_viewer_full_fn=args.out_htm_viewer_full_fn,
+      out_htm_viewer_prefix=args.out_htm_viewer_prefix,
+      w=args.width,
+      h=args.height,
+      serve_it=args.serve_it
+    )
 
 
 if __name__ == "__main__":
