@@ -15,6 +15,7 @@ from datetime import datetime
 from jgtutils import jgtcommon,iprops,jgtos
 from jgtutils import jgtos as jos
 from jgtutils.jgtos import create_filestore_path, mk_fn, mk_fn_range, mk_fullpath
+from jgtutils.jgtconstants import VOLUME
 #from jgtutils.jgtconstants import (TJAW_PERIODS,TTEETH_PERIODS)
 
 from JGTChartConfig import JGTChartConfig
@@ -28,7 +29,7 @@ addOhlc=True
 cleanseOriginalColumns=True
 useLocal=True
 
-def refreshPH(instrument:str, timeframe:str,quote_count:int=-1, quiet:bool=True,use_full:bool=False,verbose_level=0,tlid_range=None):
+def refreshPH(instrument:str, timeframe:str,quote_count:int=-1, quiet:bool=True,use_full:bool=False,verbose_level=0,tlid_range=None,keep_bid_ask=False):
   #print debug information
   # print(f"Refreshing {instrument} {timeframe}")
   # print(f"quote_count: {quote_count}")
@@ -39,7 +40,7 @@ def refreshPH(instrument:str, timeframe:str,quote_count:int=-1, quiet:bool=True,
   if not quiet:
     print(f"Refreshing {instrument} {timeframe}")
   try:
-    wsl.getPH(instrument, timeframe,quote_count=quote_count, tlid_range=tlid_range, use_full=use_full,verbose_level=verbose_level)
+    wsl.getPH(instrument, timeframe,quote_count=quote_count, tlid_range=tlid_range, use_full=use_full,verbose_level=verbose_level,keep_bid_ask=keep_bid_ask)
   except Exception as e:
     print("Error in refreshPH")
     raise e
@@ -96,7 +97,8 @@ def getPH_crop(instrument:str,
   
   df=getPH(instrument, timeframe, quiet=quiet,dt_crop_last=dt_crop_last,use_full=True,use_cache_full=use_cache_full)
   
-  return select_quote_count(quote_count, df, quiet=quiet)
+  df = select_quote_count(quote_count, df, quiet=quiet)
+  return df
 
 
 def select_quote_count(quote_count, df, quiet=True):
@@ -137,6 +139,7 @@ def getPH(instrument:str,
           use_fresh_error_ignore=False,   
           use_cache_full=False,
           keep_bid_ask=False,
+          dropna_volume=True,
           #talligator_flag=False,
           ):
   global df_full_cache
@@ -183,6 +186,11 @@ def getPH(instrument:str,
     if not use_full:
       df = df.iloc[-quote_count:]
   
+  if dropna_volume and timeframe != "M1":
+    if VOLUME in df.columns:
+      df = df.dropna(subset=[VOLUME])
+      #also drop where VOLUME is 0
+      df = df[df[VOLUME] != 0]
   return df
 
 def _get_ph_surely_fresh(instrument, timeframe, quote_count, with_index, quiet, convert_date_index_to_dt, use_full, dt_crop_last, tlid_range, run_jgtfxcli_on_error, use_fresh_error_ignore, use_cache_full,use_fresh=False,keep_bid_ask=False):
@@ -214,7 +222,7 @@ def _get_ph_surely_fresh(instrument, timeframe, quote_count, with_index, quiet,
 
   if use_fresh:
     try:
-      refreshPH(instrument, timeframe,quote_count=quote_count, tlid_range=tlid_range, use_full=use_full,verbose_level=1)
+      refreshPH(instrument, timeframe,quote_count=quote_count, tlid_range=tlid_range, use_full=use_full,verbose_level=1,keep_bid_ask=keep_bid_ask)
     except: #Raise ExceptionUseFreshData
       print("Error in getPH when using fresh")
       if use_fresh_error_ignore:
@@ -229,7 +237,7 @@ def _get_ph_surely_fresh(instrument, timeframe, quote_count, with_index, quiet,
     try: 
       if run_jgtfxcli_on_error:
         print("Running jgtfxcli")
-        refreshPH(instrument, timeframe,quote_count=quote_count, tlid_range=tlid_range, use_full=use_full,verbose_level=1)
+        refreshPH(instrument, timeframe,quote_count=quote_count, tlid_range=tlid_range, use_full=use_full,verbose_level=1,keep_bid_ask=keep_bid_ask)
       # CALL IT BACK AGAIN
         df = getPH_from_filestore(instrument, timeframe, quiet, False, with_index,convert_date_index_to_dt,use_full=use_full,tlid_range=tlid_range)
       else:
