@@ -59,6 +59,7 @@ from jgtutils.jgtconstants import (
     TJAW,
     TTEETH,
     TLIPS,
+    NB_BARS_BY_DEFAULT_IN_CDS,
 )
 
 from jgtutils import jgtos as jos
@@ -157,7 +158,7 @@ def ids_add_indicators__legacy(
     dfsrc,
     dropnavalue=True,
     quiet=True,
-    min_nb_bar_on_chart=300,
+    min_nb_bar_on_chart=NB_BARS_BY_DEFAULT_IN_CDS,
     bypass_index_reset=False,
     rq: JGTIDSRequest = None,
 ):
@@ -168,7 +169,7 @@ def ids_add_indicators__legacy(
     dfsrc (pandas.DataFrame): The input DataFrame.
     dropnavalue (bool, optional): Whether to drop rows with NaN values. Defaults to True.
     quiet (bool, optional): Whether to suppress print statements. Defaults to False.
-    min_nb_bar_on_chart (int, optional): The minimum number of bars on the chart. Defaults to 300.
+    min_nb_bar_on_chart (int, optional): The minimum number of bars on the chart. Defaults to NB_BARS_BY_DEFAULT.
     bypass_index_reset (bool, optional): Whether to bypass resetting the index. Defaults to False.
     rq (JGTIDSRequest, optional): The JGTIDSRequest object. Defaults to None.
 
@@ -180,6 +181,11 @@ def ids_add_indicators__legacy(
         #print("rq is None is ids_add_indicators__legacy")
         rq = JGTIDSRequest()
     
+    if rq.timeframe == "M1":
+        #print("rq.timeframe is M1")
+        rq.balligator_flag = False
+        rq.talligator_flag = False
+    
     # @a Migrating to the new JGTIDSRequest
     gator_oscillator_flag = rq.gator_oscillator_flag
     mfi_flag = rq.mfi_flag
@@ -403,13 +409,13 @@ def ids_add_indicators__legacy(
             # Add SQUAT Bar column to the DataFrame
             ## formula
             """
-            1. + Tick volume and + MFI  Indicator: ++ Green 
-            2. - Tick volume and - MFI  Indicator: -- Fade
-            3. - Tick volume and + MFI  Indicator: -+ Fake
-            4. + Tick volume and - MFI  Indicator: +- Squat
+            from jgtutils.jgtconstants import MFI_SQUAT_STR,MFI_FAKE_STR,MFI_FADE_STR,MFI_GREEN_STR,MFI_SQUAT_ID,MFI_FAKE_ID,MFI_FADE_ID,MFI_GREEN_ID
+            df.replace(MFI_SQUAT_STR, MFI_SQUAT_ID, inplace=True)  # Squat (+-) signal
+            df.replace(MFI_FAKE_STR, MFI_FAKE_ID, inplace=True)    # Fake (-+) signal
+            df.replace(MFI_FADE_STR, MFI_FADE_ID, inplace=True)    # Fade (--) signal
+            df.replace(MFI_GREEN_STR, MFI_GREEN_ID, inplace=True)  # Green (++) signal
             """
             #print(" ADDING SQUAT PROTO Will be in CDS Module")
-            #i['mfi_sq'] = [calculate_mfi_sq(row, i.iloc[i.index.get_loc(row.name)-1]) if i.index.get_loc(row.name) != 0 else '0' for row in i.itertuples()]
 
         except Exception as e:
             print("bw_mfi failed")
@@ -690,47 +696,6 @@ def write_ids(instrument, timeframe, use_full, cdf):
     return fpath
 
 
-def create_ids_request_from_args(args, instrument, timeframe):
-    return JGTIDSRequest.from_args(args)
-
-###################### CLEAN ME UP IF JGTIDSRequest.from_args(args) WORK >>>>>
-def create_ids_request_from_args_LEGACY(args, instrument, timeframe):
-    rq = JGTIDSRequest()
-    rq.instrument = instrument
-    #rq.keep_bid_ask = args.keepbidask # Now default to true and turn off only if needed by --rm
-    if args.rmbidask:
-        rq.keep_bid_ask = False
-    rq.timeframe = timeframe
-    rq.quotescount = args.quotescount if args.quotescount else 300
-    rq.viewpath=args.viewpath if args.viewpath else False
-    #rq.use_fresh = args.fresh if args.fresh else False
-    if args.notfresh:
-        rq.use_fresh = False
-    rq.use_full = args.full if args.full else False
-    rq.gator_oscillator_flag = (
-        args.gator_oscillator_flag if args.gator_oscillator_flag else False
-    )
-    #rq.mfi_flag = args.mfi_flag if args.mfi_flag else False
-    if args.no_mfi_flag:
-        rq.mfi_flag = False
-    rq.balligator_flag = args.balligator_flag if args.balligator_flag else False
-    rq.talligator_flag = args.talligator_flag if args.talligator_flag else False
-    rq.balligator_period_jaws = args.balligator_period_jaws
-    rq.talligator_period_jaws = args.talligator_period_jaws
-    rq.largest_fractal_period = args.largest_fractal_period
-    rq.verbose_level = args.verbose
-    
-    rq.talligator_fix_quotescount()
-    #rq=_talligator_fix_quotescount(rq)
-    _DEBUG_TALLIGATOR_FIX_24061618=False
-    if _DEBUG_TALLIGATOR_FIX_24061618:
-        print("IDS RQ Now handle the talligator_flag")
-        print("rq.talligator_flag",rq.talligator_flag)
-        print("rq.quotescount:",rq.quotescount)
-        exit(0)
-    return rq
-
-
 def createIDSService(
     rq: JGTIDSRequest = None,
     quiet=True,
